Module pgdo::cluster

source ·
Create, start, introspect, stop, and destroy PostgreSQL clusters.

Re-exports

Modules

Structs

  • Representation of a PostgreSQL cluster.

Enums

Statics

Functions

  • Determine the names of superuser roles in a cluster (that can log in).
  • A fairly simplistic but quick check: does the directory exist and does it look like a PostgreSQL cluster data directory, i.e. does it contain a file named PG_VERSION?
  • Create and start a cluster at the given path, with the given options.
  • Yields the version of PostgreSQL required to use a cluster.

Type Aliases