run

Function run 

pub fn run<P: AsRef<Path>>(
    path: P,
    options: Options<'_>,
) -> Result<ClusterGuard, CoordinateError<ClusterError>>
Create and start a cluster at the given path, with the given options.

Uses the default runtime strategy. Returns a guard which will stop the cluster when it’s dropped.