Module resource

Module resource 

A resource for a Cluster.

Structs

ClusterExclusive
ClusterFree
ClusterShared

Functions

destroy
Similar to shutdown but also attempts to destroy the cluster, i.e. remove it entirely from the filesystem.
shutdown
Shuts down the cluster if it is running and if there are no other concurrent users.
startup
Creates the cluster, if it doesn’t already exist, and starts it in a cooperative manner.
startup_if_exists
Similar to startup but does not create the cluster, and thus only succeeds if the cluster already exists.

Type Aliases

Error
HeldResource
A ResourceShared or a ResourceExclusive.
ResourceExclusive
ResourceFree
ResourceShared