pub fn destroy(resource: ResourceShared) -> Result<(State, HeldResource), Error>Expand description
Similar to shutdown but also attempts to destroy the cluster, i.e.
remove it entirely from the filesystem.
pub fn destroy(resource: ResourceShared) -> Result<(State, HeldResource), Error>Similar to shutdown but also attempts to destroy the cluster, i.e.
remove it entirely from the filesystem.