pub struct ClusterFree<'a> { /* private fields */ }

Implementations

source

impl<'a> ClusterFree<'a>

When the cluster is not locked, all one can do is check for its existence and if it is running. However, be careful of TOCTOU errors if you’re using this for more than informational purposes.