Struct pgdo::coordinate::guard::Guard

source ·
pub struct Guard<SUBJECT>
where SUBJECT: Subject,
{ /* private fields */ }
Smart pointer around a Subject that ensures the subject is stopped or destroyed when it goes out of scope.

Errors when stopping or destroying the subject are logged but otherwise ignored.

Implementations

source

impl<T> Guard<T>
where T: Subject,

source

pub fn startup<L: Into<UnlockedFile>>( lock: L, subject: T, options: T::Options<'_> ) -> Result<Self, CoordinateError<T::Error>>

Starts the given subject and returns the guard.

source

impl<T> Guard<T>
where T: Subject,

source

pub fn and_stop(self) -> Self

Configures the guard to stop the subject when it goes out of scope.

source

pub fn and_destroy(self) -> Self

Configures the guard to destroy the subject when it goes out of scope.