Enum pgdo::runtime::strategy::RuntimesOnPath
source · pub enum RuntimesOnPath {
Custom(PathBuf),
Env,
}Expand description
Find runtimes on a given path, or on PATH (from the environment).
Parses input according to platform conventions for the PATH environment
variable. See env::split_paths for details.
Variants