Module pgdo::cluster::resource

source ·
A resource for a Cluster.

Structs

Functions

  • Similar to shutdown but also attempts to destroy the cluster, i.e. remove it entirely from the filesystem.
  • Shuts down the cluster if it is running and if there are no other concurrent users.
  • Creates the cluster, if it doesn’t already exist, and starts it in a cooperative manner.
  • Similar to startup but does not create the cluster, and thus only succeeds if the cluster already exists.

Type Aliases