Structs
Functions
- Similar to
shutdownbut also attempts to destroy the cluster, i.e. remove it entirely from the filesystem. - Shuts down the cluster if it is running and if there are no other concurrent users.
- Creates the cluster, if it doesn’t already exist, and starts it in a cooperative manner.
- Similar to
startupbut does not create the cluster, and thus only succeeds if the cluster already exists.