pub fn shutdown(
resource: ResourceShared,
) -> Result<(State, HeldResource), Error>Expand description
Shuts down the cluster if it is running and if there are no other concurrent users.
The return value has two parts: the state, State, and the resource.
The state is State::Unmodified if the cluster could not be shut down or
if it was already shut down, else State::Modified.
The resource is [Left(ResourceShared)] if the cluster is already in use –
i.e. the resource passed in is returned – else [Right(ResourceExclusive)]
otherwise.