Struct pgdo::cluster::resource::ClusterFree
source · pub struct ClusterFree<'a> { /* private fields */ }Implementations
sourceimpl<'a> ClusterFree<'a>
impl<'a> ClusterFree<'a>
When the cluster is not locked, all one can do is check for its existence and if it is running. However, be careful of TOCTOU errors if you’re using this for more than informational purposes.
pub fn exists(&self) -> Result<bool, ClusterError>
pub fn running(&self) -> Result<bool, ClusterError>