Struct pgdo::cluster::resource::ClusterShared
source · pub struct ClusterShared<'a> { /* private fields */ }Implementations
When the cluster is shared, one can connect to the cluster, and execute processes. It is possible to abuse this and shutdown the cluster, for example, but that’s on you; there’s only so much that this library can do to prevent misuse.
pub fn exists(&self) -> Result<bool, ClusterError>
pub fn running(&self) -> Result<bool, ClusterError>
sourcepub fn pool(&self, database: Option<&str>) -> Result<PgPool, ClusterError>
pub fn pool(&self, database: Option<&str>) -> Result<PgPool, ClusterError>
Forwards to Cluster::pool.
sourcepub fn exec<T: AsRef<OsStr>>(
&self,
database: Option<&str>,
command: T,
args: &[T]
) -> Result<ExitStatus, ClusterError>
pub fn exec<T: AsRef<OsStr>>( &self, database: Option<&str>, command: T, args: &[T] ) -> Result<ExitStatus, ClusterError>
Forwards to Cluster::exec.