Struct pgdo::coordinate::guard::Guard
source · pub struct Guard<SUBJECT>where
SUBJECT: Subject,{ /* private fields */ }Expand description
Smart pointer around a Subject that ensures the subject is stopped or
destroyed when it goes out of scope.
Errors when stopping or destroying the subject are logged but otherwise ignored.
Implementations